/**
 * Lenguajes de Programacin: Banco en Java
 * @author Sergio Blanco Cuaresma
 * @author Jonathan Hernndez Velasco
 */

import java.util.Iterator;
import java.util.LinkedList;


public class Banco {
	private LinkedList Cuentas;
	private LinkedList Clientes;
	
  /** 
  * Constructor
  */
	Banco(){
		Cuentas = new LinkedList();
		Clientes = new LinkedList();
	}
	
  /**
  * Inserta un cliente
  * @param Cliente El cliente a aadir
  */
  public void insertarCliente(Cliente c){
    this.Clientes.add(c);
  }
  
  /**
  * Borra un cliente con el DNI especificado. Si es titular de alguna
  * cuenta tambin ser borrada.
  * @param DNI Su dni tipo "477653221-L"
  * @return Devuelve si ha sido encontrado el cliente (true) o no (false)
  */
  public boolean borrarCliente(String DNI){
    Iterator it=Clientes.iterator();
    boolean result=false;
    
    while (it.hasNext()){
      if ( ((((Cliente)(it.next())).getDNI()).compareTo(DNI))==0 ) {
        it.remove();
        result=true;
      }
    }
    this.borrarCuenta(DNI);
    
    return result;
  }
  
  /**
  * Inserta una cuenta
  */
  public void insertarCuenta(Cuenta c){
    this.Cuentas.add(c);
  }
  
  
  /**
  * Borra una cuenta que tenga de titular un cliente con el dni especificado
  * @param DNI Su dni tipo "477653221-L"
  * @return Devuelve si ha sido encontrada la cuenta (true) o no (false)
  */
  public boolean borrarCuenta(String DNI){
    Iterator it=Cuentas.iterator();
    boolean result = false;
    
    while (it.hasNext()){
      if (((((Cliente)((Cuenta)(it.next())).getTitular()).getDNI()).compareTo(DNI))==0 ) {
        it.remove();
        result=true;
      }
    }
    
    return result;
  }
  
  /**
  * Realiza la revision sobre toda las cuentas del banco
  */
  public void revision(){
    Iterator it=Cuentas.iterator();
    while (it.hasNext()){
      ((Cuenta)(it.next())).revision();
    }
  }

  /**
  * Devuelve un listado con todos los dni's de los clientes
  * @return LinkedList de Strings (DNIs)
  */
  public LinkedList listadoClientes(){
    Iterator it=Clientes.iterator();
    LinkedList result = new LinkedList();
    
    while (it.hasNext()){
      result.add( ((Cliente)(it.next())).getDNI() );
    }
    return result;
  }

  /**
  * Devuelve un listado con todos los clientes
  * @return LinkedList de Cuentas
  */  
  public LinkedList listadoCuentas(){
    return this.Cuentas;
  }
}
